summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorrstular <rok@stular.eu>2020-05-17 23:16:38 +0200
committerrstular <rok@stular.eu>2020-05-17 23:16:38 +0200
commitea1ff86ecd12b698fe776801f87138221d01a9ce (patch)
treed8cd5dfe43ed96e4518d28144bcff60c5329b8f2
parentStyling bug fixes (diff)
downloadbeziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar.gz
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar.bz2
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar.lz
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar.xz
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.tar.zst
beziapp-ea1ff86ecd12b698fe776801f87138221d01a9ce.zip
-rw-r--r--assets/css/styles.css1
-rw-r--r--assets/js/meals.js6
-rw-r--r--dist/css/styles.css1
-rw-r--r--dist/js/meals.js6
-rw-r--r--dist/pages/about.html2
-rw-r--r--dist/sw.js4
6 files changed, 13 insertions, 7 deletions
diff --git a/assets/css/styles.css b/assets/css/styles.css
index 065457f..10e4e87 100644
--- a/assets/css/styles.css
+++ b/assets/css/styles.css
@@ -305,6 +305,7 @@ table.highlight > tbody > tr:hover {
.collapsible-header {
background-color: var(--background-color);
color: var(--color-text);
+ border-bottom-color: var(--color-divider);
}
h2 {
diff --git a/assets/js/meals.js b/assets/js/meals.js
index e9b3af8..0f4230e 100644
--- a/assets/js/meals.js
+++ b/assets/js/meals.js
@@ -278,8 +278,10 @@ async function lopolisLogin() {
}
},
- error: () => {
- UIAlert( D("loginError"), "lopolisLogin(): ajax.error");
+ error: (xhr) => {
+ if (xhr.status !== 401) {
+ UIAlert( D("loginError"), "lopolisLogin(): ajax.error");
+ }
setLoading(false);
}
});
diff --git a/dist/css/styles.css b/dist/css/styles.css
index 065457f..10e4e87 100644
--- a/dist/css/styles.css
+++ b/dist/css/styles.css
@@ -305,6 +305,7 @@ table.highlight > tbody > tr:hover {
.collapsible-header {
background-color: var(--background-color);
color: var(--color-text);
+ border-bottom-color: var(--color-divider);
}
h2 {
diff --git a/dist/js/meals.js b/dist/js/meals.js
index e9b3af8..0f4230e 100644
--- a/dist/js/meals.js
+++ b/dist/js/meals.js
@@ -278,8 +278,10 @@ async function lopolisLogin() {
}
},
- error: () => {
- UIAlert( D("loginError"), "lopolisLogin(): ajax.error");
+ error: (xhr) => {
+ if (xhr.status !== 401) {
+ UIAlert( D("loginError"), "lopolisLogin(): ajax.error");
+ }
setLoading(false);
}
});
diff --git a/dist/pages/about.html b/dist/pages/about.html
index 562692d..a61ad63 100644
--- a/dist/pages/about.html
+++ b/dist/pages/about.html
@@ -142,7 +142,7 @@
<div class="row">
<p>
<small>
- ^HEAD fa9467811859cd9c2d595f5a79819ce3aca91e26
+ ^HEAD 21f22aec32a40cba0c085ca82808dd32f68cdaac
</small>
</p>
</div>
diff --git a/dist/sw.js b/dist/sw.js
index 174fe60..06cde41 100644
--- a/dist/sw.js
+++ b/dist/sw.js
@@ -3,8 +3,8 @@
// Change version to cause cache refresh
-const static_cache_name = "site-static-1.0.13-beta-fa94678";
-// latest commit is fa9467811859cd9c2d595f5a79819ce3aca91e26
+const static_cache_name = "site-static-1.0.13-beta-21f22ae";
+// latest commit is 21f22aec32a40cba0c085ca82808dd32f68cdaac
// Got them with find . -not -path '*/\.*' | sed "s/.*/\"&\",/" | grep -v sw.js
// sw.js NE SME BITI CACHAN, ker vsebuje verzijo!